@@ -111,7 +111,7 @@ class Effect(DataContainer):
 
     @property
     def display_name(self):
-        return self.meta["name"]
+        return self.meta.get("name", self.meta.get("filename", "<empty>"))
 
     @property
     def meta_string(self):
@@ -314,8 +314,25 @@ Meta-data
         print(text)
 
     def __repr__(self):
-        name = self.meta.get("name", self.meta.get("filename", "<empty>"))
-        return f'{type(self).__name__}: "{name}"'
+        return f'{type(self).__name__}: "{self.display_name}"'
 
     def __str__(self):
         return self.__repr__()
+
+    def __getitem__(self, item):
+        if isinstance(item, str) and item[0] == "#":
+            if len(item) > 1:
+                if item[-1] == "!":
+                    key = item[1:-1]
+                    if len(key) > 0:
+                        value = from_currsys(self.meta[key])
+                    else:
+                        value = from_currsys(self.meta)
+                else:
+                    value = self.meta[item[1:]]
+            else:
+                value = self.meta
+        else:
+            raise ValueError(f"__getitem__ calls must start with '#': {item}")
+
+        return value
\ No newline at end of file
