@@ -693,11 +693,12 @@ class FieldConstantPSF(DiscretePSF):
 
 class FieldVaryingPSF(DiscretePSF):
     """
-    kwargs
-    ------
-    sub_pixel_flag
-    flux_accuracy : float
+    Parameters
+    ----------
+    sub_pixel_flag : bool, optional
+    flux_accuracy : float, optional
         Default 1e-3. Level of flux conservation during rescaling of kernel
+
     """
     def __init__(self, **kwargs):
         # sub_pixel_flag and flux_accuracy are taken care of in PSF base class
@@ -809,7 +810,6 @@ class FieldVaryingPSF(DiscretePSF):
         # .. todo: should the mask also be rescaled?
         # rescale the pixel scale of the kernel to match the fov images
         pix_ratio = fov_pixel_scale / kernel_pixel_scale
-        print(fov_pixel_scale, kernel_pixel_scale)
         if abs(pix_ratio - 1) > self.meta["flux_accuracy"]:
             for ii in range(len(self.kernel)):
                 self.kernel[ii][0] = pu.rescale_kernel(self.kernel[ii][0], pix_ratio)
