@@ -100,8 +100,13 @@ def get_imaging_waveset(effects_list, **kwargs):
     wave_bin_edges = [filt.fov_grid(which="waveset", **kwargs)
                       for filt in filters]
     if len(wave_bin_edges) > 0:
-        kwargs["wave_min"] = np.min(wave_bin_edges)
-        kwargs["wave_max"] = np.max(wave_bin_edges)
+        kwargs["wave_min"] = np.max([w[0].value for w in wave_bin_edges])
+        kwargs["wave_max"] = np.min([w[1].value for w in wave_bin_edges])
+    wave_bin_edges = [[kwargs["wave_min"], kwargs["wave_max"]]]
+
+    if kwargs["wave_min"] > kwargs["wave_max"]:
+        raise ValueError("Filter wavelength ranges do not overlap: {}"
+                         "".format(wave_bin_edges))
 
     # ..todo: add in Atmospheric dispersion and ADC here
     for effect_class in [efs.PSF]:
@@ -157,6 +162,7 @@ def get_imaging_headers(effects, **kwargs):
 
     # look for apertures
     aperture_effects = get_all_effects(effects, (efs.ApertureMask,
+                                                 efs.SlitWheel,
                                                  efs.ApertureList))
     if len(aperture_effects) == 0:
         detector_arrays = get_all_effects(effects, efs.DetectorList)
@@ -272,10 +278,13 @@ def get_spectroscopy_headers(effects, **kwargs):
                      "wave_min", "wave_max"]
     check_keys(kwargs, required_keys, action="error")
 
-    surface_list_effects = get_all_effects(effects, efs.SurfaceList)
+    surface_list_effects = get_all_effects(effects, (efs.SurfaceList,
+                                                     efs.FilterWheel,
+                                                     efs.FilterCurve))
     detector_list_effects = get_all_effects(effects, efs.DetectorList)
     spec_trace_effects = get_all_effects(effects, efs.SpectralTraceList)
     aperture_effects = get_all_effects(effects, (efs.ApertureList,
+                                                 efs.SlitWheel,
                                                  efs.ApertureMask))
 
     if len(surface_list_effects) > 0:
@@ -386,4 +395,4 @@ def combine_wavesets(waveset_list):
     # ..todo:: set variable in !SIM.computing for rounding to the 7th decimal
     wave_set = np.unique(np.round(np.sort(wave_set, kind="stable"), 7))
 
-    return wave_set
\ No newline at end of file
+    return wave_set
